@@ -3,12 +3,16 @@
 import copy
 import hashlib
 import logging
-from collections import OrderedDict
+import sys
+
 from os import remove
 from os.path import splitext, join, exists, isfile, split
 from pathlib import Path
-from posixpath import basename
-from typing import Optional, Dict, Iterator, Union, List, Any, Tuple, Callable
+from typing import Optional, Dict, Iterator, Union, List, Any, Callable, Tuple
+if sys.version_info[:2] >= (3, 7):
+    OrderedDict = dict
+else:
+    from collections import OrderedDict
 
 import requests
 import tabulator
@@ -18,7 +22,7 @@ from ruamel.yaml import YAML
 from six.moves.urllib.parse import urlsplit, urlunsplit, parse_qsl, urlencode
 
 from hdx.utilities import raisefrom
-from hdx.utilities.path import get_temp_dir
+from hdx.utilities.path import get_temp_dir, get_filename_from_url
 from hdx.utilities.session import get_session
 
 logger = logging.getLogger(__name__)
@@ -117,8 +121,7 @@ class Download(object):
                 raise DownloadError('Cannot use folder or filename and path arguments together!')
             folder, filename = split(path)
         if not filename:
-            urlpath = urlsplit(url).path
-            filename = basename(urlpath)
+            filename = get_filename_from_url(url)
         filename, extension = splitext(filename)
         if not folder:
             folder = get_temp_dir()
@@ -342,6 +345,49 @@ class Download(object):
         """
         return self.setup(url, stream=False, post=post, parameters=parameters, timeout=timeout, headers=headers, encoding=encoding)
 
+    def get_header(self, header):
+        # type: (str) -> Any
+        """Get a particular response header of download
+
+        Args:
+            header (str): Header for which to get value
+
+        Returns:
+            Any: Response header's value
+
+        """
+        return self.response.headers.get(header)
+
+    def get_headers(self):
+        # type: () -> Any
+        """Get response headers of download
+
+        Returns:
+            Any: Response headers
+
+        """
+        return self.response.headers
+
+    def get_status(self):
+        # type: () -> int
+        """Get response status code
+
+        Returns:
+            int: Response status code
+
+        """
+        return self.response.status_code
+
+    def get_text(self):
+        # type: () -> str
+        """Get text content of download
+
+        Returns:
+            str: Text content of download
+
+        """
+        return self.response.text
+
     def get_yaml(self):
         # type: () -> Any
         """Get YAML content of download
