@@ -2,6 +2,7 @@
 """Downloader Tests"""
 import copy
 import re
+import sys
 from collections import OrderedDict
 from os import remove
 from os.path import join, abspath
@@ -186,11 +187,18 @@ class TestDownloader:
     def test_get_url_for_get(self):
         assert Download.get_url_for_get('http://www.lala.com/hdfa?a=3&b=4', OrderedDict(
             [('c', 'e'), ('d', 'f')])) == 'http://www.lala.com/hdfa?a=3&b=4&c=e&d=f'
+        if sys.version_info[:2] >= (3, 7):
+            assert Download.get_url_for_get('http://www.lala.com/hdfa?a=3&b=4', {'c': 'e', 'd': 'f'}) == \
+                   'http://www.lala.com/hdfa?a=3&b=4&c=e&d=f'
 
     def test_get_url_params_for_post(self):
-        assert Download.get_url_params_for_post('http://www.lala.com/hdfa?a=3&b=4',
-                                                OrderedDict([('c', 'e'), ('d', 'f')])) == (
-                   'http://www.lala.com/hdfa', OrderedDict([('a', '3'), ('b', '4'), ('c', 'e'), ('d', 'f')]))
+        result = Download.get_url_params_for_post('http://www.lala.com/hdfa?a=3&b=4', OrderedDict([('c', 'e'), ('d', 'f')]))
+        assert result[0]  == 'http://www.lala.com/hdfa'
+        assert list(result[1].items())  == list(OrderedDict([('a', '3'), ('b', '4'), ('c', 'e'), ('d', 'f')]).items())
+        if sys.version_info[:2] >= (3, 7):
+            result = Download.get_url_params_for_post('http://www.lala.com/hdfa?a=3&b=4', {'c': 'e', 'd': 'f'})
+            assert result[0] == 'http://www.lala.com/hdfa'
+            assert list(result[1].items()) == list(OrderedDict([('a', '3'), ('b', '4'), ('c', 'e'), ('d', 'f')]).items())
 
     def test_hxl_row(self):
         headers = ['a', 'b', 'c']
@@ -215,10 +223,10 @@ class TestDownloader:
             assert bool(re.match(r'4\d\d', headers['Content-Length'])) is True
             downloader.setup('%s?id=10&lala=a' % getfixtureurl, post=False,
                              parameters=OrderedDict([('b', '4'), ('d', '3')]))
-            assert downloader.get_json()['args'] == OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')])
+            assert list(downloader.get_json()['args'].items()) == list(OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')]).items())
             downloader.setup('%s?id=3&lala=b' % postfixtureurl, post=True,
                              parameters=OrderedDict([('a', '3'), ('c', '2')]))
-            assert downloader.get_json()['form'] == OrderedDict([('a', '3'), ('c', '2'), ('id', '3'), ('lala', 'b')])
+            assert list(downloader.get_json()['form'].items()) == list(OrderedDict([('a', '3'), ('c', '2'), ('id', '3'), ('lala', 'b')]).items())
 
     def test_hash_stream(self, fixtureurl):
         with Download() as downloader:
@@ -285,20 +293,29 @@ class TestDownloader:
         with pytest.raises(DownloadError), Download() as downloader:
             downloader.download(fixturenotexistsurl)
         with Download() as downloader:
-            result = downloader.download(fixtureurl)
-            assert bool(re.match(r'7\d\d', result.headers['Content-Length'])) is True
+            downloader.download(fixtureurl)
+            assert downloader.get_status() == 200
+            assert len(downloader.get_headers()) == 24
+            assert bool(re.match(r'7\d\d', downloader.get_header('Content-Length'))) is True
+            assert downloader.get_text() == '''GWNO,EVENT_ID_CNTY,EVENT_ID_NO_CNTY,EVENT_DATE,YEAR,TIME_PRECISION,EVENT_TYPE,ACTOR1,ALLY_ACTOR_1,INTER1,ACTOR2,ALLY_ACTOR_2,INTER2,INTERACTION,COUNTRY,ADMIN1,ADMIN2,ADMIN3,LOCATION,LATITUDE,LONGITUDE,GEO_PRECISION,SOURCE,NOTES,FATALITIES
+615,1416RTA,,18/04/2001,2001,1,Violence against civilians,Police Forces of Algeria (1999-),,1,Civilians (Algeria),Berber Ethnic Group (Algeria),7,17,Algeria,Tizi Ouzou,Beni-Douala,,Beni Douala,36.61954,4.08282,1,Associated Press Online,A Berber student was shot while in police custody at a police station in Beni Douala. He later died on Apr.21.,1
+615,2229RTA,,19/04/2001,2001,1,Riots/Protests,Rioters (Algeria),Berber Ethnic Group (Algeria),5,Police Forces of Algeria (1999-),,1,15,Algeria,Tizi Ouzou,Tizi Ouzou,,Tizi Ouzou,36.71183,4.04591,3,Kabylie report,"Riots were reported in numerous villages in Kabylie, resulting in dozens wounded in clashes between protesters and police and significant material damage.",0
+615,2230RTA,,20/04/2001,2001,1,Riots/Protests,Protesters (Algeria),Students (Algeria),6,,,0,60,Algeria,Bejaia,Amizour,,Amizour,36.64022,4.90131,1,Crisis Group,Students protested in the Amizour area. At least 3 were later arrested for allegedly insulting gendarmes.,0
+615,2231RTA,,21/04/2001,2001,1,Riots/Protests,Rioters (Algeria),Berber Ethnic Group (Algeria),5,Police Forces of Algeria (1999-),,1,15,Algeria,Bejaia,Amizour,,Amizour,36.64022,4.90131,1,Kabylie report,"Rioters threw molotov cocktails, rocks and burning tires at gendarmerie stations in Beni Douala, El-Kseur and Amizour.",0
+
+'''
             downloader.download('%s?id=10&lala=a' % getfixtureurl, post=False,
                                 parameters=OrderedDict([('b', '4'), ('d', '3')]))
-            assert downloader.get_json()['args'] == OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')])
+            assert list(downloader.get_json()['args'].items()) == list(OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')]).items())
             downloader.download('%s?id=3&lala=b' % postfixtureurl, post=True,
                                 parameters=OrderedDict([('a', '3'), ('c', '2')]))
-            assert downloader.get_json()['form'] == OrderedDict([('a', '3'), ('c', '2'), ('id', '3'), ('lala', 'b')])
+            assert list(downloader.get_json()['form'].items()) == list(OrderedDict([('a', '3'), ('c', '2'), ('id', '3'), ('lala', 'b')]).items())
         with Download(rate_limit={'calls': 1, 'period': 0.1}) as downloader:
             downloader.download('%s?id=10&lala=a' % getfixtureurl, post=False,
                                 parameters=OrderedDict([('b', '4'), ('d', '3')]))
-            assert downloader.get_json()['args'] == OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')])
+            assert list(downloader.get_json()['args'].items()) == list(OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')]).items())
             downloader.download(fixturefile)
-            assert downloader.get_yaml()['mykey'] == OrderedDict([('param1', 'value 1'), ('param2', 'value2'), ('param3', 11), ('basic_auth', 'Basic dGVzdHVzZXI6dGVzdHBhc3M=')])
+            assert list(downloader.get_yaml()['mykey'].items()) == list(OrderedDict([('param1', 'value 1'), ('param2', 'value2'), ('param3', 11), ('basic_auth', 'Basic dGVzdHVzZXI6dGVzdHBhc3M=')]).items())
 
     def test_download_tabular_key_value(self, fixtureurl, fixtureprocessurl):
         with Download() as downloader:
